@@ -370,8 +370,8 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 		try:
 			if group == '*':
 			    r = l.search_s("ou=groups," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixGroup)',   ['cn'])
-            else:
-            	r = l.search_s("cn="+group+"ou=groups," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixGroup)',   ['cn']) 
+			else:
+				r = l.search_s("cn="+group+",ou=groups," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixGroup)',   ['cn']) 
 
 		except ldap.NO_SUCH_OBJECT:
 			print "No groups found"
@@ -386,7 +386,7 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 	
 
 	# grab complete informaton on all groups from db 
-	if group == '*'
+	if group == '*':
 	    sql = "SELECT `cn`, `description`, `gidNumber` from jos_xgroups"
 	else:
 	    sql = "SELECT `cn`, `description`, `gidNumber` from jos_xgroups WHERE cn='" + group + "'"
