@@ -707,7 +707,7 @@ def add_ldap_user2(cn,
 		#	traceback.print_exc()
 		
 
-def syncuser(user, hubname = "", purgeorphans = True, syncattributes = True, user = '*'):
+def syncuser(user, hubname = "", purgeorphans = True, syncattributes = True):
      _syncusers(hubname, purgeorphans, syncattributes, user)
 
 def syncusers(hubname = "", purgeorphans = True, syncattributes = True):
@@ -747,10 +747,10 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 		l = ldap.initialize(ldapServer)
 		l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
 
-        if user == '*':
-		    r = l.search_s("ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
+		if user == '*':
+			r = l.search_s("ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
 		else:
-			r = l.search_s("uid="+user+"ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
+			r = l.search_s("uid="+user+",ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
 
 		for dn,entry in r:
 			uid = str(entry['uid'][0])
